@@ -43,10 +43,17 @@ typedef struct
 {
     GObjectClass 		 parent_class;
     
+    void			(*shuffle_toggled)		    (ParolePlayer *list,
+								     gboolean shuffle_toggled);
+								     
+	void			(*repeat_toggled)		    (ParolePlayer *list,
+								     gboolean repeat_toggled);
+
+    
 } ParolePlayerClass;
 
 GType        			 parole_player_get_type        (void) G_GNUC_CONST;
-ParolePlayer       		*parole_player_new             (void);
+ParolePlayer       		*parole_player_new             (const gchar *client_id);
 
 ParoleMediaList			*parole_player_get_media_list  (ParolePlayer *player);
 
